Crate ethbridge_bridge_calls

Crate ethbridge_bridge_calls 

Structs

CurrentBridgeValidatorSetHashCall
Container type for all input parameters for the currentBridgeValidatorSetHash function with signature currentBridgeValidatorSetHash() and selector 0x7379d426
CurrentBridgeValidatorSetHashReturn
Container type for all return fields from the currentBridgeValidatorSetHash function with signature currentBridgeValidatorSetHash() and selector 0x7379d426
CurrentGovernanceValidatorSetHashCall
Container type for all input parameters for the currentGovernanceValidatorSetHash function with signature currentGovernanceValidatorSetHash() and selector 0x0df6a752
CurrentGovernanceValidatorSetHashReturn
Container type for all return fields from the currentGovernanceValidatorSetHash function with signature currentGovernanceValidatorSetHash() and selector 0x0df6a752
NextBridgeValidatorSetHashCall
Container type for all input parameters for the nextBridgeValidatorSetHash function with signature nextBridgeValidatorSetHash() and selector 0xf5cd6594
NextBridgeValidatorSetHashReturn
Container type for all return fields from the nextBridgeValidatorSetHash function with signature nextBridgeValidatorSetHash() and selector 0xf5cd6594
NextGovernanceValidatorSetHashCall
Container type for all input parameters for the nextGovernanceValidatorSetHash function with signature nextGovernanceValidatorSetHash() and selector 0x1c461a91
NextGovernanceValidatorSetHashReturn
Container type for all return fields from the nextGovernanceValidatorSetHash function with signature nextGovernanceValidatorSetHash() and selector 0x1c461a91
TransferToChainCall
Container type for all input parameters for the transferToChain function with signature transferToChain((uint256,address,string)[],uint256) and selector 0x224738eb
TransferToChainNonceCall
Container type for all input parameters for the transferToChainNonce function with signature transferToChainNonce() and selector 0x21b1eb5f
TransferToChainNonceReturn
Container type for all return fields from the transferToChainNonce function with signature transferToChainNonce() and selector 0x21b1eb5f
TransferToErc20NonceCall
Container type for all input parameters for the transferToErc20Nonce function with signature transferToErc20Nonce() and selector 0x5f9fd577
TransferToErc20NonceReturn
Container type for all return fields from the transferToErc20Nonce function with signature transferToErc20Nonce() and selector 0x5f9fd577
TransferToErcCall
Container type for all input parameters for the transferToErc function with signature transferToErc((bytes32[],uint256),(bytes32,bytes32,uint8)[],((bytes32,uint256,address,address)[],bytes32,bytes32[],bool[],uint256,string)) and selector 0x998c0030
UpdateValidatorSetCall
Container type for all input parameters for the updateValidatorSet function with signature updateValidatorSet((bytes32[],uint256),bytes32,bytes32,(bytes32,bytes32,uint8)[]) and selector 0xfd48739e
UpgradeCall
Container type for all input parameters for the upgrade function with signature upgrade((bytes32[],uint256),(bytes32,bytes32,uint8)[],address,uint256) and selector 0xc3203d76
UpgradeNonceCall
Container type for all input parameters for the upgradeNonce function with signature upgradeNonce() and selector 0x1af628b9
UpgradeNonceReturn
Container type for all return fields from the upgradeNonce function with signature upgradeNonce() and selector 0x1af628b9
ValidatorSetNonceCall
Container type for all input parameters for the validatorSetNonce function with signature validatorSetNonce() and selector 0x486f2e46
ValidatorSetNonceReturn
Container type for all return fields from the validatorSetNonce function with signature validatorSetNonce() and selector 0x486f2e46
WithdrawCall
Container type for all input parameters for the withdraw function with signature withdraw((bytes32[],uint256),(bytes32,uint256,address,address)[],(bytes32,bytes32,uint8)[],uint256) and selector 0x43d80041
WithdrawNonceCall
Container type for all input parameters for the withdrawNonce function with signature withdrawNonce() and selector 0xb8a4e151
WithdrawNonceReturn
Container type for all return fields from the withdrawNonce function with signature withdrawNonce() and selector 0xb8a4e151

Enums

BridgeCalls
Container type for all of the contract’s call