pub struct TransferToChainCall {
pub transfers: Vec<ChainTransfer>,
pub confirmations: U256,
}Expand description
Container type for all input parameters for the transferToChain function with signature transferToChain((uint256,address,string)[],uint256) and selector 0x224738eb
Fields
transfers: Vec<ChainTransfer>confirmations: U256Trait Implementations
Sourceimpl AbiDecode for TransferToChainCall
impl AbiDecode for TransferToChainCall
Sourceimpl AbiEncode for TransferToChainCall
impl AbiEncode for TransferToChainCall
Sourceimpl AbiType for TransferToChainCall
impl AbiType for TransferToChainCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for TransferToChainCall
impl Clone for TransferToChainCall
Sourcefn clone(&self) -> TransferToChainCall
fn clone(&self) -> TransferToChainCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransferToChainCall
impl Debug for TransferToChainCall
Sourceimpl Default for TransferToChainCall
impl Default for TransferToChainCall
Sourcefn default() -> TransferToChainCall
fn default() -> TransferToChainCall
Returns the “default value” for a type. Read more
Sourceimpl Display for TransferToChainCall
impl Display for TransferToChainCall
Sourceimpl EthCall for TransferToChainCall
impl EthCall for TransferToChainCall
Sourceimpl From<TransferToChainCall> for BridgeCalls
impl From<TransferToChainCall> for BridgeCalls
Sourcefn from(value: TransferToChainCall) -> Self
fn from(value: TransferToChainCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for TransferToChainCall
impl Hash for TransferToChainCall
Sourceimpl PartialEq for TransferToChainCall
impl PartialEq for TransferToChainCall
Sourceimpl Tokenizable for TransferToChainCall
impl Tokenizable for TransferToChainCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for TransferToChainCall
impl Eq for TransferToChainCall
impl StructuralPartialEq for TransferToChainCall
impl TokenizableItem for TransferToChainCall