pub struct TransferToChainNonceReturn(pub U256);Expand description
Container type for all return fields from the transferToChainNonce function with signature transferToChainNonce() and selector 0x21b1eb5f
Tuple Fields
0: U256Trait Implementations
Sourceimpl AbiType for TransferToChainNonceReturn
impl AbiType for TransferToChainNonceReturn
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for TransferToChainNonceReturn
impl Clone for TransferToChainNonceReturn
Sourcefn clone(&self) -> TransferToChainNonceReturn
fn clone(&self) -> TransferToChainNonceReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransferToChainNonceReturn
impl Debug for TransferToChainNonceReturn
Sourceimpl Default for TransferToChainNonceReturn
impl Default for TransferToChainNonceReturn
Sourcefn default() -> TransferToChainNonceReturn
fn default() -> TransferToChainNonceReturn
Returns the “default value” for a type. Read more
Sourceimpl Hash for TransferToChainNonceReturn
impl Hash for TransferToChainNonceReturn
Sourceimpl Tokenizable for TransferToChainNonceReturn
impl Tokenizable for TransferToChainNonceReturn
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for TransferToChainNonceReturn
impl Eq for TransferToChainNonceReturn
impl StructuralPartialEq for TransferToChainNonceReturn
impl TokenizableItem for TransferToChainNonceReturn