Container type for all input parameters for the currentBridgeValidatorSetHash function with signature currentBridgeValidatorSetHash() and selector 0x7379d426
Container type for all return fields from the currentBridgeValidatorSetHash function with signature currentBridgeValidatorSetHash() and selector 0x7379d426
Container type for all input parameters for the currentGovernanceValidatorSetHash function with signature currentGovernanceValidatorSetHash() and selector 0x0df6a752
Container type for all return fields from the currentGovernanceValidatorSetHash function with signature currentGovernanceValidatorSetHash() and selector 0x0df6a752
Container type for all input parameters for the nextBridgeValidatorSetHash function with signature nextBridgeValidatorSetHash() and selector 0xf5cd6594
Container type for all input parameters for the nextGovernanceValidatorSetHash function with signature nextGovernanceValidatorSetHash() and selector 0x1c461a91
Container type for all return fields from the nextGovernanceValidatorSetHash function with signature nextGovernanceValidatorSetHash() and selector 0x1c461a91
Container type for all input parameters for the transferToChain function with signature transferToChain((uint256,address,string)[],uint256) and selector 0x224738eb
Container type for all input parameters for the transferToErc function with signature transferToErc((bytes32[],uint256),(bytes32,bytes32,uint8)[],((bytes32,uint256,address,address)[],bytes32,bytes32[],bool[],uint256,string)) and selector 0x998c0030
Container type for all input parameters for the updateValidatorSet function with signature updateValidatorSet((bytes32[],uint256),bytes32,bytes32,(bytes32,bytes32,uint8)[]) and selector 0xfd48739e
Container type for all input parameters for the upgrade function with signature upgrade((bytes32[],uint256),(bytes32,bytes32,uint8)[],address,uint256) and selector 0xc3203d76
Container type for all input parameters for the withdraw function with signature withdraw((bytes32[],uint256),(bytes32,uint256,address,address)[],(bytes32,bytes32,uint8)[],uint256) and selector 0x43d80041